/****************************************************************
 *								*
 * Copyright (c) 2001-2018 Fidelity National Information	*
 * Services, Inc. and/or its subsidiaries. All rights reserved.	*
 *								*
 *	This source code contains the intellectual property	*
 *	of its copyright holder(s), and is made available	*
 *	under a license.  If you do not know the terms of	*
 *	the license, please stop and do not read further.	*
 *								*
 ****************************************************************/

#ifndef BM_UPDATE_H_INCLUDED
#define BM_UPDATE_H_INCLUDED

void bm_update(cw_set_element *cs, sm_uc_ptr_t lclmap, boolean_t is_mm);

#endif
